@@ -11,7 +11,9 @@ import {
   SET_PROPERTIES,
   REMOVE,
   UNDO,
-  ROLLBACK
+  ROLLBACK,
+  OPEN_PROJECT_CONFIGURATOR,
+  SET_PROJECT_PROPERTIES
 } from '../constants';
 
 export function loadProject(data) {
@@ -109,3 +111,16 @@ export function rollback() {
     type: ROLLBACK
   }
 }
+
+export function openProjectConfigurator() {
+  return {
+    type: OPEN_PROJECT_CONFIGURATOR
+  }
+}
+
+export function setProjectProperties(properties) {
+  return {
+    type: SET_PROJECT_PROPERTIES,
+    properties
+  }
+}
