@@ -1,5 +1,6 @@
 import Planner from './components/planner';
 import Catalog from './catalog/catalog';
+import Translator from './translator/translator';
 import ToolbarButton from './components/toolbar/toolbar-button';
 import Ruler from './components/viewer2d/ruler';
 import * as Models from './models'
@@ -10,5 +11,5 @@ import AppReducer from './reducers/reducer';
 console.info(`react-planner started`); //MIT LICENSE COMPLIANT
 
 export {
-  Planner, Catalog, ToolbarButton, Ruler, Models, PluginBrowserAutosave, State2DViewer, AppReducer
+  Planner, Catalog, Translator, ToolbarButton, Ruler, Models, PluginBrowserAutosave, State2DViewer, AppReducer
 };
